Crate only_syntax

Crate only_syntax 

Structs

DiagnosticCode
DirectiveNode
Typed directive CST wrapper.
DocCommentNode
Typed doc-comment CST wrapper.
DocumentNode
Typed document CST wrapper.
LexToken
NamespaceNode
Typed namespace CST wrapper.
ParseResult
SyntaxSnapshot
Immutable syntax snapshot shared by semantic analysis and editor hosts.
TaskDependencyRef
One dependency reference parsed from a task header.
TaskHeaderInfo
Structured task header data parsed from the CST token stream.
TaskNode
Typed task CST wrapper.

Enums

SyntaxKind

Traits

ParseResultExt
Extension helpers for parse results used by hosts and tests.

Functions

lex
Lexes source text into tokens while preserving trivia.
parse
Parses Onlyfile text into a shallow CST with line-level recovery.
snapshot
Lexes and parses source text into an immutable syntax snapshot.

Type Aliases

SyntaxNode
SyntaxToken