pub fn bootstrap(
source: &str,
runner_version: &str,
) -> Result<BootstrapHeader, Diagnostic>Expand description
Runs the header scan and compatibility check without parsing the full file.
pub fn bootstrap(
source: &str,
runner_version: &str,
) -> Result<BootstrapHeader, Diagnostic>Runs the header scan and compatibility check without parsing the full file.