pub fn scan_bootstrap_header(
source: &str,
) -> Result<BootstrapHeader, Diagnostic>Expand description
Scans the optional version declaration at the start of an Onlyfile.
pub fn scan_bootstrap_header(
source: &str,
) -> Result<BootstrapHeader, Diagnostic>Scans the optional version declaration at the start of an Onlyfile.