pub fn snapshot(source: &str) -> SyntaxSnapshotExpand description
Lexes and parses source text into an immutable syntax snapshot.
Args: source: Raw Onlyfile source text.
Returns: Snapshot containing tokens, CST and syntax diagnostics.
pub fn snapshot(source: &str) -> SyntaxSnapshotLexes and parses source text into an immutable syntax snapshot.
Args: source: Raw Onlyfile source text.
Returns: Snapshot containing tokens, CST and syntax diagnostics.