pub struct TaskDependencyRef {
pub name: SmolStr,
pub range: TextRange,
pub stage: usize,
}Expand description
One dependency reference parsed from a task header.
Args: None.
Returns: Dependency text and the precise source range of that reference.
Fields
name: SmolStrrange: TextRangestage: usizeTrait Implementations
Sourceimpl Clone for TaskDependencyRef
impl Clone for TaskDependencyRef
Sourcefn clone(&self) -> TaskDependencyRef
fn clone(&self) -> TaskDependencyRef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TaskDependencyRef
impl Debug for TaskDependencyRef
Sourceimpl PartialEq for TaskDependencyRef
impl PartialEq for TaskDependencyRef
Sourcefn eq(&self, other: &TaskDependencyRef) -> bool
fn eq(&self, other: &TaskDependencyRef) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for TaskDependencyRef
impl StructuralPartialEq for TaskDependencyRef