DirectiveNode

Struct DirectiveNode 

pub struct DirectiveNode { /* private fields */ }
Typed directive CST wrapper.

Args: None.

Returns: Stable accessors for directive name, value and span.

Implementations

Source

impl DirectiveNode

pub fn cast(syntax: SyntaxNode) -> Option<Self>

Casts a raw rowan node into a typed directive wrapper.

Args: syntax: Raw rowan syntax node.

Returns: Typed directive wrapper when the kind matches Directive.

pub fn range(&self) -> TextRange

Returns the directive text range.

Args: None.

Returns: Directive range in source text coordinates.

pub fn keyword_range(&self) -> Option<TextRange>

Returns the directive keyword range including the leading !.

Args: None.

Returns: Range covering !echo or !shell when present.

pub fn name(&self) -> Option<SmolStr>

Returns the directive name token text without the leading !.

Args: None.

Returns: Directive name when present.

pub fn value(&self) -> Option<SmolStr>

Returns the directive value text after the directive name.

Args: None.

Returns: Joined directive value text when present.